@@ -20,7 +20,6 @@
 using namespace ost;
 using namespace std;
 
-BayonneDriver *Bayonne::start_driver = NULL;
 BayonneSession **Bayonne::timeslots = NULL;
 Bayonne::timeslot_t Bayonne::ts_count = 0;
 Bayonne::timeslot_t Bayonne::ts_used = 0;
@@ -42,9 +41,14 @@ time_t Bayonne::start_time = 0;
 AtomicCounter Bayonne::libexec_count = 0;
 unsigned Bayonne::compile_count;
 volatile bool Bayonne::image_loaded = false;
+bool Bayonne::provision_ripple = true;
+bool Bayonne::provision_daemon = false;
 bool Bayonne::provision_system = false;
+bool Bayonne::provision_check = false;
 bool Bayonne::provision_user = false;
+bool Bayonne::provision_test = false;
 const char *Bayonne::provision_server = "bayonne";
+const char *Bayonne::provision_libexec = "libexec";
 
 Audio::Encoding Bayonne::peer_encoding = Audio::unknownEncoding;
 Audio::timeout_t Bayonne::peer_framing = 0;
@@ -112,43 +116,119 @@ void Bayonne::waitLoaded(void)
 	}
 }
 
-bool Bayonne::loadPlugin(const char *prefix, const char *path)
+bool Bayonne::loadPlugin(const char *path)
 {
         char pathbuf[256];
         const char *cp, *kv;
+	const char *prefix = NULL;
         DSO *dso;
 
 #ifdef	WIN32
-	if(!prefix)
-		"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins";
+#ifdef	HAVE_TESTING
+        if(!prefix && provision_test)
+#ifdef  NDEBUG
+                prefix = "DEBUG";
 #else
+                prefix = "RELEASE";
+#endif 
+#endif
+	if(!prefix)
+		prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins";
+#else
+        char prefixbuf[256];
+
+#ifdef	HAVE_TESTING
+        if(!prefix && provision_test && !strchr(path, '/'))
+        {
+                snprintf(prefixbuf, sizeof(prefixbuf),
+                        "%s/modules/%s/.libs", SOURCE_FILES, path);
+                if(!isDir(prefixbuf))  
+                        snprintf(prefixbuf, sizeof(prefixbuf),
+                                "%s/modules/%s", SOURCE_FILES, path);
+                prefix = prefixbuf;
+        } 
+#endif
 	if(!prefix)
 		prefix = LIBDIR_FILES;
 #endif
 
-        cp = strrchr(path, '/');
-        if(!cp)
-                cp = strrchr(path, '\\');
-        if(!cp)
-                cp = strrchr(path, ':');
-        if(!cp)
-        {
 #ifdef  WIN32
-                snprintf(pathbuf, sizeof(pathbuf),
-                        "%s/%s." RLL_SUFFIX, prefix, path);
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, path);
 #else
-                if(!strnicmp(prefix, "..", 2))
-                        snprintf(pathbuf, sizeof(pathbuf),
-                        "%s/%s/.libs/%s.dso", prefix, path, path);
-                else
-                        snprintf(pathbuf, sizeof(pathbuf),
-                                "%s/%s.dso", prefix, path);
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.dso", prefix, path);
 #endif  
-                cp = path;
-                path = pathbuf;
+        cp = path;
+        path = pathbuf;
+
+        kv = server->getLast(path);
+        if(kv)
+        {
+                if(!stricmp(kv, "loaded"))
+                        return true;
+		return false;
+	}
+
+        if(!canAccess(path))
+        {
+                errlog("access", "cannot load %s", path);
+                return false;
         }
-        else
-                ++cp;
+
+        dso = new DSO(path);
+        if(!dso->isValid())
+        {
+                kv = dso->getError();
+                server->setValue(path, kv);
+                errlog("error", "cannot initialize %s", path);
+                return false;
+        }
+        server->setValue(path, "loaded");
+        return true;                
+}
+
+bool Bayonne::loadMonitor(const char *path)
+{
+        char pathbuf[256];
+        const char *cp, *kv;
+	const char *prefix = NULL;
+        DSO *dso;
+
+#ifdef	WIN32
+#ifdef	HAVE_TESTING
+        if(!prefix && provision_test)
+#ifdef  NDEBUG
+                prefix = "DEBUG";
+#else
+                prefix = "RELEASE";
+#endif 
+#endif
+	if(!prefix)
+		"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Monitor";
+#else
+        char prefixbuf[256];
+
+#ifdef	HAVE_TESTING
+        if(!prefix && provision_test && !strchr(path, '/'))
+        {
+                snprintf(prefixbuf, sizeof(prefixbuf),
+                        "%s/modules/%smon/.libs", SOURCE_FILES, path);
+                if(!isDir(prefixbuf))  
+                        snprintf(prefixbuf, sizeof(prefixbuf),
+                                "%s/modules/%smon", SOURCE_FILES, path);
+                prefix = prefixbuf;
+        } 
+#endif
+	if(!prefix)
+		prefix = LIBDIR_FILES;
+#endif
+
+#ifdef  WIN32
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, path);
+#else
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.mon", prefix, path);
+#endif  
+        cp = path;
+        path = pathbuf;
 
         kv = server->getLast(path);
         if(kv)
@@ -400,88 +480,6 @@ BayonneSession *Bayonne::getSession(timeslot_t timeslot)
 	return timeslots[timeslot];
 }
 
-void Bayonne::compileDir(const char *prefix, ScriptCompiler *img)
-{
-	Dir dir(prefix);
-	char path[256];
-	const char *ext;
-	const char *file;
-	unsigned len;
-	char *pp;
-	
-	slog.info("compiler scanning %s", prefix);
-	setString(path, sizeof(path), prefix);
-	len = strlen(path);
-	pp = path + len;
-	len = sizeof(path) - len;
-
-	*pp++ = '/';
-	--len;
-
-	while(NULL != (file = dir.getName()))
-	{
-		if(*file == '.')
-			continue;
-
-		ext = strrchr(file, '.');
-		if(ext && strstr(Script::exec_extensions, ext))
-			goto compile;
-
-		if(ext && !stricmp(ext, ".scr"))
-			goto compile;
-
-		if(ext && !stricmp(ext, ".mac"))
-			goto compile;
-
-		continue;
-compile:
-		++compile_count;
-		setString(pp, len, file);
-		img->compile(path);
-	}
-}
-
-void Bayonne::compileApps(const char *prefix, ScriptCompiler *img)
-{
-	Dir dir(prefix);
-	char path[256];
-	const char *ext;
-	const char *file;
-	unsigned len;
-	char *pp;
-	
-	slog.info("apps scanning %s", prefix);
-	setString(path, sizeof(path), prefix);
-	len = strlen(path);
-	pp = path + len;
-	len = sizeof(path) - len;
-
-	*pp++ = '/';
-	--len;
-
-	while(NULL != (file = dir.getName()))
-	{
-		ext = strrchr(file, '.');
-		if(ext && !stricmp(ext, ".app"))
-			goto compile;
-
-		if(ext && !stricmp(ext, ".apps"))
-			goto compile;
-
-#ifndef	WIN32
-		if(ext && !stricmp(ext, ".exec"))
-			goto compile;
-#endif
-
-		continue;
-compile:
-		++compile_count;
-		setString(pp, len, file);
-		img->compile(path);
-	}
-}
-
-
 bool Bayonne::service(const char *id)
 {
 	bool rtn = false;
@@ -539,10 +537,6 @@ ScriptCompiler *Bayonne::reload(void)
 	static Mutex lock;
 
 	ScriptCompiler *img;
-	const char *prefix;
-	unsigned count;
-	char **keys;
-	char *ext;
 
 	if(!server)
 		return NULL;
@@ -553,62 +547,14 @@ ScriptCompiler *Bayonne::reload(void)
 #ifdef	WIN32
 	img = new ScriptCompiler(server, "/bayonne/config");
 #else
-	img = new ScriptCompiler(server, "/bayonne/server/config");
+	img = new ScriptCompiler(server, getKeypath("/bayonne/server/config"));
 	if(provision_system)
 		img->loadPrefix("config", "/bayonne/provision/config");
 	else if(provision_user)
 		img->loadPrefix("config", "~bayonne/config");
 #endif
 
-	count = server->Keydata::getCount();
-	keys = new char *[count + 1];
-
-	count = server->Keydata::getIndex(keys, count + 1);
-	while(count)
-	{
-		prefix = *(keys++);
-		if(!prefix)
-			break;
-
-		ext = strrchr(prefix, '.');
-		if(ext && strstr(Script::exec_extensions, ext))
-			goto compile;
-
-		if(!ext || stricmp(ext, ".scr"))
-			continue;
-compile:
-		++compile_count;
-		prefix = server->getLast(prefix);
-		img->compile(prefix);
-	}
-
-        prefix = server->getLast("addons");
-        if(prefix)
-        {
-                if(isDir(prefix))
-                        compileDir(prefix, img);
-                else
-        		slog.error() << prefix << ": directory missing" << endl;
-        } 
-
-	prefix = server->getLast("scripts");
-	if(prefix)
-	{
-		if(isDir(prefix))
-			compileDir(prefix, img);
-		else
-			slog.error() << prefix << ": directory missing" << endl;
-	}
-
-	prefix = server->getLast("apps");
-	if(prefix)
-	{
-		if(isDir(prefix))
-			compileApps(prefix, img);
-		else
-			slog.error() << prefix << ": directory missing" << endl;
-	}
-
+	ScriptBinder::rebuild(img);
 	img->commit();
 	lock.leave();
 	if(compile_count)
@@ -727,6 +673,7 @@ void Bayonne::errlog(const char *level, const char *fmt, ...)
         }
         else
                 slog.error() << buffer << endl;
-                                                  
-	Bayonne::server->errlog(level, buffer);
+
+	if(Bayonne::server) 	                                                 
+		Bayonne::server->errlog(level, buffer);
 }
