@@ -1641,6 +1641,33 @@ public:
 		{return driver;};
 };
 
+/**
+ * An intermediary binder class for Bayonne engine.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short Binder class.
+ */
+class __EXPORT BayonneBinder : public ScriptBinder, public Bayonne
+{
+private:
+	static BayonneBinder *binder;
+
+protected:
+	virtual Name *service(ScriptImage *img, ScriptInterp *interp, const char *sid);
+
+	BayonneSession *session(ScriptInterp *interp);
+
+	bool scriptEvent(ScriptInterp *interp, const char *evt);
+
+	bool digitEvent(ScriptInterp *interp, const char *evt);
+
+	BayonneBinder(const char *id);
+
+public:
+	static Name *getService(ScriptImage *img, ScriptInterp *interp, const char *sid);
+
+};
+
 /**
  * The primary session object representing a server timeslot and active
  * communication endpoint in Bayonne.
@@ -2216,6 +2243,9 @@ public:
 	 */
 	bool digitEvent(const char *evt);
 
+	inline bool stringEvent(const char *evt)
+		{return scriptEvent(evt);}
+
 	/**
 	 * Get the next pending digit in the DTMF input buffer.
 	 *
