@@ -1323,9 +1323,6 @@ bool BayonneSession::stateRinging(Event *event)
 
 bool BayonneSession::stateIdle(Event *event)
 {
-	char buf[65];
-	const char *cid, *did, *cinfo;
-	
 	if(enterIdle(event))
 		return true;
 
@@ -1368,79 +1365,13 @@ bool BayonneSession::stateIdle(Event *event)
 
 attach:
 		if(attachStart(event))
-		{
-			did = getSymbol("session.dialed");
-			cid = getSymbol("session.caller");
-			cinfo = getSymbol("session.info");
-			switch(type)
-			{
-			case DIRECT:
-				type = INCOMING;
-				if(cinfo && *cinfo)
-				{
-					snprintf(buf, sizeof(buf), "info:%s", cinfo);
-					if(scriptEvent(buf))
-						break;	
-				}
-				if(cid && *cid)
-				{
-					snprintf(buf, sizeof(buf), "caller:%s", cid);
-					if(digitEvent(buf))
-						break;
-				}
-				break;
-			case FORWARDED:
-				if(did && *did)
-				{
-					snprintf(buf, sizeof(buf), "dialed:%s", did);
-					if(digitEvent(buf))
-						break;
-				}
-				scriptEvent("incoming:forward");
-				break;
-			case RECALL:
-				scriptEvent("incoming:recall");
-				break;
-			case PICKUP:
-				if(cid && *cid)
-				{
-					snprintf(buf, sizeof(buf), "caller:%s", cid);
-					if(digitEvent(buf))
-						break;
-				}
-				scriptEvent("incoming:pickup");
-				break;
-			case INCOMING:
-				if(cinfo && *cinfo)
-				{
-					snprintf(buf, sizeof(buf), "info:%s", cinfo);
-					if(scriptEvent(buf))
-						break;
-				}
-				if(did && *did)
-				{
-					snprintf(buf, sizeof(buf), "dialed:%s", did);
-					if(digitEvent(buf))
-						break;
-				}
-				if(cid && *cid)
-				{
-					snprintf(buf, sizeof(buf), "caller:%s", cid);
-					if(digitEvent(buf))
-						break;
-				}
-			default:
-				if(ring_count)
-					scriptEvent("incoming:ringing");
-				else
-					scriptEvent("incoming:immediate");
-			}
 			setState(STATE_PICKUP);
-			return true;
+		else
+		{
+			type = NONE;
+			slog.error("%s: start failed", logname);
+			purge();
 		}
-		type = NONE;
-		slog.error("%s: start failed", logname);
-		purge();
 		return true;
 	case START_OUTGOING:
 		type = OUTGOING;
