@@ -31,6 +31,12 @@
 
 #include "driver.h"
 
+#ifdef  WIN32
+#define CONFIG_FILES    "C:/Program Files/GNU Telephony/Bayonne Config"
+#else
+#include <private.h>
+#endif 
+
 namespace h323driver {
 using namespace ost;
 using namespace std;
@@ -102,6 +108,15 @@ BayonneDriver(driver, KEYS, "h323", false)
 	cp = getLast("offer");
 	if(cp)
 		ring_timer = atoi(cp);
+
+#ifdef	HAVE_TESTING
+	if(Bayonne::provision_testing)
+	{
+		server->setValue("h323.conf", SOURCE_FILES "/config/h323.conf");
+		return;
+	}
+#endif
+	server->setValue("h323.conf", CONFIG_FILES "/h323.conf");	
 }
 
 void Driver::startDriver(void)
