@@ -16,8 +16,12 @@
 
 #include "driver.h"
 
-#ifdef	WIN32
+
+#ifdef  WIN32
+#define CONFIG_FILES    "C:/Program Files/GNU Telephony/Bayonne Config"
 #define	strdup	ost::strdup
+#else
+#include <private.h>
 #endif
 
 namespace sipdriver {
@@ -77,6 +81,9 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	else if(Bayonne::provision_user)
 		load("~bayonne/sip");
 #endif
+
+
+
 	cp = getLast("ack");
 	if(!cp)
 		cp = getLast("acktimer");
@@ -191,6 +198,17 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 		codec->encode(silent_frame, silent_encoded, info.framecount);
 		AudioCodec::endCodec(codec);
 	}	
+
+#ifdef	HAVE_TESTING
+        if(Bayonne::provision_test)
+        {    
+		server->setValue("sip.conf", SOURCE_FILES "/config/sip.conf");
+		server->setValue("uri.conf", SOURCE_FILES "/config/uri.conf");
+		return;
+	}
+#endif
+	server->setValue("sip.conf", CONFIG_FILES "/sip.conf");
+	server->setValue("uri.conf", CONFIG_FILES "/uri.conf");
 }
 
 void Driver::startDriver(void)
@@ -219,7 +237,6 @@ void Driver::startDriver(void)
 	if(!count)
 		return;
 
-
 #ifdef	HAVE_EXOSIP2
 	eXosip_init();
 
@@ -875,8 +892,16 @@ void Driver::run(void)
 			cp = strchr(caller, '@');
 			if(cp && !reg)
 			{
-				snprintf(buf, sizeof(buf), "sip.%s", ++cp);
-				scr = (Name *)img->getPointer(buf);
+				if(Bayonne::provision_ripple)
+				{
+					snprintf(buf, sizeof(buf), "uri::%s", ++cp);
+					scr = img->getScript(buf);
+				}
+				else
+				{
+					snprintf(buf, sizeof(buf), "sip.%s", ++cp);
+					scr = (Name *)img->getPointer(buf);
+				}
 				if(scr)
 					auth = "friend"; // anon peer
 			}
@@ -885,8 +910,16 @@ void Driver::run(void)
 				cp += 4;
 			if(cp && !reg && !scr)
 			{
-				snprintf(buf, sizeof(buf), "sip.%s", ++cp);
-				scr = (Name *)img->getPointer(buf);
+				if(Bayonne::provision_ripple)
+				{
+					snprintf(buf, sizeof(buf), "uri::%s", cp);
+					scr = img->getScript(buf);
+				}
+				else
+				{
+					snprintf(buf, sizeof(buf), "sip.%s", cp);
+					scr = (Name *)img->getPointer(buf);
+				}
 			}
 
 			if(!reg && !scr)
