@@ -474,6 +474,13 @@ sub result($$) {
 	return $self->command("result $buf");
 }
 
+# transfer extension
+
+sub transfer($$) {
+	my($self, $dest) = @_;
+	return $self->command("xfer $dest");
+}
+
 # get symbol value
 
 sub get($$) {
