@@ -199,11 +199,35 @@ const char *Checks::chkTone(Line *line, ScriptImage *img)
 	return NULL;
 }
 
+const char *Checks::chkList(Line *line, ScriptImage *img)
+{
+	unsigned idx = 0;
+	const char *cp;
+
+	if(getMember(line))
+		return "list has no members";
+
+	if(!useKeywords(line, "=prefix=match=extension"))
+		return "invalid keyword for list";
+
+	cp = getOption(line, &idx);
+	if(!cp)
+		return "list missing result argument";
+
+	if(*cp != '&' && *cp != '%')
+		return "list result argument must be a symbol";
+
+	if(!getOption(line, &idx))
+		return "list missing directory argument";
+
+	return NULL;
+}
+
 const char *Checks::chkDir(Line *line, ScriptImage *img)
 {
 	unsigned count = 0;
 	const char *cp;
-	char path[256];
+	char path[MAX_PATHNAME];
 
 	if(getMember(line))
 		return "dir has no members";
