@@ -55,6 +55,8 @@ ScriptRuntime()
 			(Check)&Checks::chkLoad},
 		{"dir", true, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkDir},
+		{"list", true, (Method)&Methods::scrList,
+			(Check)&Checks::chkList},
 		{"pathname", false, (Method)&Methods::scrPathname,
 			(Check)&Checks::chkPathname},
 		{"readpath", true, (Method)&Methods::scrReadpath,
