@@ -42,6 +42,19 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+class ListThread : public ScriptThread, public Dir
+{
+private:
+	const char *prefix, *suffix;
+	Symbol *sym;
+
+	void run(void);
+
+public:
+	ListThread(ScriptInterp *interp, const char *dir, Symbol *var);
+	~ListThread();	
+};
+	
 class InfoThread : public ScriptThread
 {
 private:
@@ -160,6 +173,7 @@ public:
 class Methods : public BayonneSession
 {
 public:
+	bool scrList(void);
 	bool scrEcho(void);
 	bool scrPickup(void);
 	bool scrHangup(void);
@@ -201,6 +215,7 @@ public:
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
+	const char *chkList(Line *line, ScriptImage *img);
 	const char *chkConfig(Line *line, ScriptImage *img);
 	const char *chkPaths(Line *line, ScriptImage *img);
 	const char *chkTonegen(Line *line, ScriptImage *img);
