@@ -22,6 +22,53 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+ListThread::ListThread(ScriptInterp *interp, const char *path, Symbol *var) :
+ScriptThread(interp, 0), Dir(path) 
+{
+	sym = var;
+	prefix = interp->getKeyword("match");
+	suffix = interp->getKeyword("extension");
+}
+
+ListThread::~ListThread()
+{
+	Dir::close();
+}
+
+void ListThread::run(void)
+{
+	const char *name;
+	unsigned len, slen = 0;
+
+	if(suffix)
+		slen = strlen(suffix);
+
+	while(NULL != (name = Dir::getName()))
+	{
+		if(*name == '.')
+			continue;
+
+		if(prefix && strnicmp(name, prefix, strlen(prefix)))
+			continue;
+
+		if(slen)
+		{
+			len = strlen(name);
+			if(len < slen)
+				continue;
+			len -= slen;
+			if(stricmp(name + len, suffix))
+				continue;
+		}
+
+		interp->enter();
+		interp->append(sym, name);
+		interp->leave();
+	}
+
+	exit(NULL);
+}
+
 BuildThread::BuildThread(ScriptInterp *interp, BayonneAudio *au, Audio::Info *inf, const char *d, const char **list) :
 ScriptThread(interp, 0)
 {
